/* Siconos is a program dedicated to modeling, simulation and control
 * of non smooth dynamical systems.
 *
 * Copyright 2020 INRIA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

/** \file CircularDS.hpp
 */

/** \class CircularDS
    \brief Definition of a 2D circular shape - Inherits from LagrangianDS
*/


#ifndef CircularDS_h
#define CircularDS_h

#include "MechanicsFwd.hpp"
#include "LagrangianDS.hpp"

class CircularDS : public LagrangianDS
{
protected:
  /** serialization hooks
  */
  ACCEPT_SERIALIZATION(CircularDS);

  double radius;
  double massValue;

  CircularDS(): LagrangianDS() {};

public:

  CircularDS(double, double, SP::SiconosVector, SP::SiconosVector);

  virtual ~CircularDS() {};

  inline double getQ(unsigned int pos)
  {
    assert(pos < _ndof);
    return (*_q[0])(pos);
  };
  inline double getVelocity(unsigned int pos)
  {
    assert(pos < _ndof);
    return (*_q[1])(pos);
  };

  inline double getMassValue() const
  {
    return massValue;
  };

  inline double getRadius() const
  {
    return radius;
  };

};
#endif /* CircularDS_h */
