/* Siconos is a program dedicated to modeling, simulation and control
 * of non smooth dynamical systems.
 *
 * Copyright 2020 INRIA.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

/** \file Disk.hpp
 */

#ifndef Disk_H
#define Disk_H

#include "MechanicsFwd.hpp"
#include "CircularDS.hpp"
/** \class Disk
 *  \brief Definition of a 2D disk - Inherits from LagrangianDS
 */


class Disk : public CircularDS, public std::enable_shared_from_this<Disk>
{
private:
  /** serialization hooks
  */
  ACCEPT_SERIALIZATION(Disk);


  void MassSetup();

protected:
  Disk() : CircularDS() {};

public:

  /** Constructor
      \param radius
      \param mass
      \param position vector
      \param velocity vector
  */

  Disk(double radius, double mass, SP::SiconosVector position, SP::SiconosVector velocity);

  /** destructor
   */
  virtual ~Disk();


  /** visitors hook
   */
  ACCEPT_BASE_VISITORS(LagrangianDS);

};
#endif /* Disk_H */

